<?php

namespace App\Http\Controllers;

use App\Http\Requests\CustomerRequest;
use App\Models\Customer;
use App\Models\PackingSlip;
use App\Models\ShippingEntry;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;

class CustomerController extends Controller
{
    public function index(Request $request)
    {
        return view('customers.index', [
            'customers' => Customer::all(),
            'tab' => $request->tab,
        ]);
    }

    public function store(CustomerRequest $request)
    {
        Customer::create($request->validated());

        return redirect()->route('customers.index')->with('status', 'Customer created successfully.');
    }

    public function create()
    {
        return view('customers.create');
    }

    public function show(Customer $customer, string $tab = null)
    {
        if (!$tab) {
            return redirect()->route('customers.show', [$customer, 'tab' => 'details']);
        }

        $orders = $customer->orders();
        $priorities = '"production", "approved", "order"';

        return view('customers.show', [
            'tab' => $tab,
            'customer' => $customer,
            'active_orders' => $orders
                ->where('status', '!=', 'cancelled')
                ->where('status', '!=', 'completed')
                ->orderBy('rush', 'desc')
                ->orderBy('due_date', 'desc')
                ->paginate(10),
            'contacts' => $customer->contacts()->get(),
            'packingSlips' => PackingSlip::where('customer_id', $customer->id)->orderByDesc('date_received')->paginate(15),
            'shippingEntries' => $customer->shippingEntries()->get(),
            'today' => Carbon::today()->format('Y-m-d'),
        ]);
    }

    public function update(CustomerRequest $request, Customer $customer)
    {
        $customer->update($request->validated());

        return redirect()->route('customers.show', $customer)->with('status', 'Customer updated successfully.');
    }

    public function requestDestroy(Request $request)
    {
        $customer = Customer::find($request->id);
        $customer->delete();

        return redirect()->route('customers.index')->with('status', 'Customer deleted successfully.');
    }

    public function destroy(Customer $customer)
    {
        $customer->delete();

        return redirect()->route('customers.index')->with('status', 'Customer deleted successfully.');
    }
}
